import React, { useEffect, useRef } from "react";
import { MdCancel } from "react-icons/md";
import styles from './styles.module.css';
import { Checkbox } from "../../components/base/checkbox/Index";

const List = ({
  store,
  editIndex,
  renderEditableContent,
  startEdit,
  toggleComplete,
  Delete,
  isNewTodoAdded
}) => {
  const listEndRef = useRef(null);
  const listContainerRef = useRef(null);

  useEffect(() => {
    if (isNewTodoAdded && listEndRef.current) {
      listEndRef.current.scrollIntoView({ 
        behavior: 'smooth' 
      });
    }
  }, [store.length, isNewTodoAdded]);

  return (
    <div className={styles.scrollContainer} ref={listContainerRef}>
      <ul className={styles.scroll}>
        {store.map((item, index) => {
          if (!item || typeof item.task === 'undefined') return null;

          return (
            <li key={item.id ?? index} className={`${styles.todo} ${item.completed ? styles.completed : ""}`}>
              <div className={styles.check}>
                <Checkbox
                  checked={item.completed}
                  onChange={() => toggleComplete(index)}
                  id={item.id}
                />
                {editIndex === index ? (
                  renderEditableContent()
                ) : (
                  <span
                    className={`${styles.task} ${item.completed ? styles.completed : ''}`}
                    onClick={(e) => startEdit(index,e)}
                  >
                    {typeof item.task === 'string'
                      ? item.task
                      : JSON.stringify(item.task)}
                  </span>
                )}
              </div>
              <button className={styles.delete} onClick={() => Delete(item.id)}>
                <MdCancel />
              </button>
            </li>
          );
        })}
        <li ref={listEndRef} style={{ height: 0 }} />
      </ul>
    </div>
  );
};

export default List;